Summary: Library of Optimized Inner Loops, CPU optimized functions
Name: liboil
Version: 0.3.17
Release: 1
# See COPYING which details everything, various BSD licenses apply
License: BSD
Group: System Environment/Libraries
URL: http://liboil.freedesktop.org/
Source0: http://liboil.freedesktop.org/download/%{name}-%{version}.tar.gz
Patch0: %{name}-%{version}-aix.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: glib2-devel >= 2.22.4

%description
Liboil is a library of simple functions that are optimized for various CPUs.
These functions are generally loops implementing simple algorithms, such as
converting an array of N integers to floating-poing numbers or multiplying
and summing an array of N numbers. Clearly such functions are candidates for
significant optimization using various techniques, especially by using
extended instructions provided by modern CPUs (Altivec, MMX, SSE, etc.).


%package devel
Summary: Development files and static library for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}, pkg-config

%description devel
Liboil is a library of simple functions that are optimized for various CPUs.
These functions are generally loops implementing simple algorithms, such as
converting an array of N integers to floating-poing numbers or multiplying
and summing an array of N numbers. Clearly such functions are candidates for
significant optimization using various techniques, especially by using
extended instructions provided by modern CPUs (Altivec, MMX, SSE, etc.).


%prep
%setup -q
%patch0


%build
# setup GNU GCC build environment
export CFLAGS="-DSYSV -D_AIX -D_AIX32 -D_AIX41 -D_AIX43 -D_AIX51 -D_ALL_SOURCE -DFUNCPROTO=15 -O -I/opt/freeware/include"

export CXX=g++
export CXXFLAGS=$CFLAGS

export LD=ld
export LDFLAGS="-L/opt/freeware/lib"

# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"
export NM="nm -X32_64"

# first build the 64-bit version
# on purpose we configure the "--build=powerpc-ibm-aix5.1.0.0" option
# differently from what config.guess provides
export CC="gcc -maix64 -mcpu=power3"
./configure \
    --build=ibm-aix5.1.0.0 \
    --prefix=%{_prefix}
make %{?_smp_mflags}

cp %{name}/.libs/%{name}-0.3.so.0 .
make clean

# now build the 32-bit version
# on purpose we configure the "--build=powerpc-ibm-aix5.1.0.0" option
# differently from what config.guess provides
export CC="gcc -maix32 -mcpu=power3"
./configure \
    --build=ibm-aix5.1.0.0 \
    --prefix=%{_prefix}
make %{?_smp_mflags}

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
${AR} -q %{name}/.libs/%{name}-0.3.a ./%{name}-0.3.so.0


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
make install DESTDIR=${RPM_BUILD_ROOT}

/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc AUTHORS COPYING BUG-REPORTING NEWS README
%{_libdir}/*.a
/usr/lib/*.a


%files devel
%defattr(-,root,system,-)
%doc %{_datadir}/gtk-doc/html/%{name}
%{_bindir}/oil-bugreport
%{_includedir}/*
%{_libdir}/*.la
%{_libdir}/pkgconfig/*.pc
/usr/bin/oil-bugreport
/usr/include/*
/usr/lib/*.la


%changelog
* Fri Apr 09 2010 Michael Perzl <michael@perzl.org> - 0.3.17-1
- first version for AIX5L v5.1 and higher
